@@ -53,7 +53,10 @@ _shared_modules = [
     expr_pb2,
 ]
 
-_local_modules = [asset_service_pb2, assets_pb2]
+_local_modules = [
+    asset_service_pb2,
+    assets_pb2,
+]
 
 names = []
 
