@@ -26,9 +26,15 @@ from google.iam.v1 import policy_pb2
 from google.type import expr_pb2
 
 
-_shared_modules = [policy_pb2, expr_pb2]
+_shared_modules = [
+    policy_pb2,
+    expr_pb2,
+]
 
-_local_modules = [asset_service_pb2, assets_pb2]
+_local_modules = [
+    asset_service_pb2,
+    assets_pb2,
+]
 
 names = []
 
